# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.utilities import currency_pb2 as v1_dot_utilities_dot_currency__pb2


class CurrencyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CurrencyAdd = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.currency.CurrencyService/CurrencyAdd",
            request_serializer=v1_dot_utilities_dot_currency__pb2.CurrencyAddRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_currency__pb2.CurrencyAddResponse.FromString,
        )
        self.CurrencyRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.currency.CurrencyService/CurrencyRead",
            request_serializer=v1_dot_utilities_dot_currency__pb2.CurrencyReadRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_currency__pb2.CurrencyReadResponse.FromString,
        )
        self.CurrencyUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.currency.CurrencyService/CurrencyUpdate",
            request_serializer=v1_dot_utilities_dot_currency__pb2.CurrencyUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_currency__pb2.CurrencyUpdateResponse.FromString,
        )
        self.CurrencyDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.utilities.currency.CurrencyService/CurrencyDelete",
            request_serializer=v1_dot_utilities_dot_currency__pb2.CurrencyDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_utilities_dot_currency__pb2.CurrencyDeleteResponse.FromString,
        )


class CurrencyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CurrencyAdd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CurrencyRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CurrencyUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CurrencyDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CurrencyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CurrencyAdd": grpc.unary_unary_rpc_method_handler(
            servicer.CurrencyAdd,
            request_deserializer=v1_dot_utilities_dot_currency__pb2.CurrencyAddRequest.FromString,
            response_serializer=v1_dot_utilities_dot_currency__pb2.CurrencyAddResponse.SerializeToString,
        ),
        "CurrencyRead": grpc.unary_unary_rpc_method_handler(
            servicer.CurrencyRead,
            request_deserializer=v1_dot_utilities_dot_currency__pb2.CurrencyReadRequest.FromString,
            response_serializer=v1_dot_utilities_dot_currency__pb2.CurrencyReadResponse.SerializeToString,
        ),
        "CurrencyUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.CurrencyUpdate,
            request_deserializer=v1_dot_utilities_dot_currency__pb2.CurrencyUpdateRequest.FromString,
            response_serializer=v1_dot_utilities_dot_currency__pb2.CurrencyUpdateResponse.SerializeToString,
        ),
        "CurrencyDelete": grpc.unary_unary_rpc_method_handler(
            servicer.CurrencyDelete,
            request_deserializer=v1_dot_utilities_dot_currency__pb2.CurrencyDeleteRequest.FromString,
            response_serializer=v1_dot_utilities_dot_currency__pb2.CurrencyDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.utilities.currency.CurrencyService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CurrencyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CurrencyAdd(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.currency.CurrencyService/CurrencyAdd",
            v1_dot_utilities_dot_currency__pb2.CurrencyAddRequest.SerializeToString,
            v1_dot_utilities_dot_currency__pb2.CurrencyAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CurrencyRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.currency.CurrencyService/CurrencyRead",
            v1_dot_utilities_dot_currency__pb2.CurrencyReadRequest.SerializeToString,
            v1_dot_utilities_dot_currency__pb2.CurrencyReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CurrencyUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.currency.CurrencyService/CurrencyUpdate",
            v1_dot_utilities_dot_currency__pb2.CurrencyUpdateRequest.SerializeToString,
            v1_dot_utilities_dot_currency__pb2.CurrencyUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CurrencyDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.utilities.currency.CurrencyService/CurrencyDelete",
            v1_dot_utilities_dot_currency__pb2.CurrencyDeleteRequest.SerializeToString,
            v1_dot_utilities_dot_currency__pb2.CurrencyDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/country.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/stock/country.proto\x12!pro.omni.oms.api.v1.stock.country\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xcb\x01\n\x07\x43ountry\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x16\n\x0e\x63ountry_doc_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x97\x01\n\x14\x43ountryCreateRequest\x12\x16\n\x0e\x63ountry_doc_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43ountryCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63ountry\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country"\xf0\x02\n\x12\x43ountryReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xda\x01\n\x13\x43ountryReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12=\n\tcountries\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country"\x8b\x01\n\x14\x43ountryUpdateRequest\x12;\n\x07\x63ountry\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15\x43ountryUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07\x63ountry\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.stock.country.Country"Z\n\x14\x43ountryDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x43ountryDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa5\x04\n\x0e\x43ountryService\x12\x84\x01\n\rCountryCreate\x12\x37.pro.omni.oms.api.v1.stock.country.CountryCreateRequest\x1a\x38.pro.omni.oms.api.v1.stock.country.CountryCreateResponse"\x00\x12~\n\x0b\x43ountryRead\x12\x35.pro.omni.oms.api.v1.stock.country.CountryReadRequest\x1a\x36.pro.omni.oms.api.v1.stock.country.CountryReadResponse"\x00\x12\x84\x01\n\rCountryUpdate\x12\x37.pro.omni.oms.api.v1.stock.country.CountryUpdateRequest\x1a\x38.pro.omni.oms.api.v1.stock.country.CountryUpdateResponse"\x00\x12\x84\x01\n\rCountryDelete\x12\x37.pro.omni.oms.api.v1.stock.country.CountryDeleteRequest\x1a\x38.pro.omni.oms.api.v1.stock.country.CountryDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.country_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_COUNTRY"]._serialized_start = 113
    _globals["_COUNTRY"]._serialized_end = 316
    _globals["_COUNTRYCREATEREQUEST"]._serialized_start = 319
    _globals["_COUNTRYCREATEREQUEST"]._serialized_end = 470
    _globals["_COUNTRYCREATERESPONSE"]._serialized_start = 473
    _globals["_COUNTRYCREATERESPONSE"]._serialized_end = 632
    _globals["_COUNTRYREADREQUEST"]._serialized_start = 635
    _globals["_COUNTRYREADREQUEST"]._serialized_end = 1003
    _globals["_COUNTRYREADRESPONSE"]._serialized_start = 1006
    _globals["_COUNTRYREADRESPONSE"]._serialized_end = 1224
    _globals["_COUNTRYUPDATEREQUEST"]._serialized_start = 1227
    _globals["_COUNTRYUPDATEREQUEST"]._serialized_end = 1366
    _globals["_COUNTRYUPDATERESPONSE"]._serialized_start = 1369
    _globals["_COUNTRYUPDATERESPONSE"]._serialized_end = 1528
    _globals["_COUNTRYDELETEREQUEST"]._serialized_start = 1530
    _globals["_COUNTRYDELETEREQUEST"]._serialized_end = 1620
    _globals["_COUNTRYDELETERESPONSE"]._serialized_start = 1622
    _globals["_COUNTRYDELETERESPONSE"]._serialized_end = 1720
    _globals["_COUNTRYSERVICE"]._serialized_start = 1723
    _globals["_COUNTRYSERVICE"]._serialized_end = 2272
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_locality_matrix_values.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n.v1/rules/delivery_locality_matrix_values.proto\x12\x39pro.omni.oms.api.v1.rules.delivery_locality_matrix_values\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xee\x01\n\x1c\x44\x65liveryLocalityMatrixValues\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1c\n\x14\x64\x65livery_locality_id\x18\x02 \x01(\x05\x12"\n\x1aterritory_matrix_values_id\x18\x03 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xba\x01\n)DeliveryLocalityMatrixValuesCreateRequest\x12\x1c\n\x14\x64\x65livery_locality_id\x18\x01 \x01(\x05\x12"\n\x1aterritory_matrix_values_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfa\x01\n*DeliveryLocalityMatrixValuesCreateResponse\x12\x80\x01\n\x1f\x64\x65livery_locality_matrix_values\x18\x01 \x01(\x0b\x32W.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValues\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x85\x03\n\'DeliveryLocalityMatrixValuesReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb4\x02\n(DeliveryLocalityMatrixValuesReadResponse\x12\x81\x01\n delivery_locality_matrix_valuess\x18\x01 \x03(\x0b\x32W.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValues\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xe6\x01\n)DeliveryLocalityMatrixValuesUpdateRequest\x12\x80\x01\n\x1f\x64\x65livery_locality_matrix_values\x18\x01 \x01(\x0b\x32W.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValues\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfa\x01\n*DeliveryLocalityMatrixValuesUpdateResponse\x12\x80\x01\n\x1f\x64\x65livery_locality_matrix_values\x18\x01 \x01(\x0b\x32W.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValues\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"o\n)DeliveryLocalityMatrixValuesDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"w\n*DeliveryLocalityMatrixValuesDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf7\x07\n#DeliveryLocalityMatrixValuesService\x12\xf3\x01\n"DeliveryLocalityMatrixValuesCreate\x12\x64.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesCreateRequest\x1a\x65.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesCreateResponse"\x00\x12\xed\x01\n DeliveryLocalityMatrixValuesRead\x12\x62.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesReadRequest\x1a\x63.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesReadResponse"\x00\x12\xf3\x01\n"DeliveryLocalityMatrixValuesUpdate\x12\x64.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesUpdateRequest\x1a\x65.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesUpdateResponse"\x00\x12\xf3\x01\n"DeliveryLocalityMatrixValuesDelete\x12\x64.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesDeleteRequest\x1a\x65.pro.omni.oms.api.v1.rules.delivery_locality_matrix_values.DeliveryLocalityMatrixValuesDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_locality_matrix_values_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYLOCALITYMATRIXVALUES"]._serialized_start = 161
    _globals["_DELIVERYLOCALITYMATRIXVALUES"]._serialized_end = 399
    _globals["_DELIVERYLOCALITYMATRIXVALUESCREATEREQUEST"]._serialized_start = 402
    _globals["_DELIVERYLOCALITYMATRIXVALUESCREATEREQUEST"]._serialized_end = 588
    _globals["_DELIVERYLOCALITYMATRIXVALUESCREATERESPONSE"]._serialized_start = 591
    _globals["_DELIVERYLOCALITYMATRIXVALUESCREATERESPONSE"]._serialized_end = 841
    _globals["_DELIVERYLOCALITYMATRIXVALUESREADREQUEST"]._serialized_start = 844
    _globals["_DELIVERYLOCALITYMATRIXVALUESREADREQUEST"]._serialized_end = 1233
    _globals["_DELIVERYLOCALITYMATRIXVALUESREADRESPONSE"]._serialized_start = 1236
    _globals["_DELIVERYLOCALITYMATRIXVALUESREADRESPONSE"]._serialized_end = 1544
    _globals["_DELIVERYLOCALITYMATRIXVALUESUPDATEREQUEST"]._serialized_start = 1547
    _globals["_DELIVERYLOCALITYMATRIXVALUESUPDATEREQUEST"]._serialized_end = 1777
    _globals["_DELIVERYLOCALITYMATRIXVALUESUPDATERESPONSE"]._serialized_start = 1780
    _globals["_DELIVERYLOCALITYMATRIXVALUESUPDATERESPONSE"]._serialized_end = 2030
    _globals["_DELIVERYLOCALITYMATRIXVALUESDELETEREQUEST"]._serialized_start = 2032
    _globals["_DELIVERYLOCALITYMATRIXVALUESDELETEREQUEST"]._serialized_end = 2143
    _globals["_DELIVERYLOCALITYMATRIXVALUESDELETERESPONSE"]._serialized_start = 2145
    _globals["_DELIVERYLOCALITYMATRIXVALUESDELETERESPONSE"]._serialized_end = 2264
    _globals["_DELIVERYLOCALITYMATRIXVALUESSERVICE"]._serialized_start = 2267
    _globals["_DELIVERYLOCALITYMATRIXVALUESSERVICE"]._serialized_end = 3282
# @@protoc_insertion_point(module_scope)
